==> phoenix-starter-cloudt-0.1.14-20240118.092859-1-sources.jar: com/elitesland/cbpl/unicom/context/Customize.java <==
package com.elitesland.cbpl.unicom.context;

import cn.hutool.core.util.ReflectUtil;
import io.swagger.annotations.ApiModel;
import lombok.Data;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author eric.hao
 * @since 2022/03/21
 */
@Data
@ApiModel("定制开发版本")
public class Customize {

    /**
     * 通用标准实施
     */
    public final static String CUSTOMIZE_STANDARD = "STANDARD";

    /**
     * 九毛九餐饮
     */
    public final static String CUSTOMIZE_JIUMAOJIU = "JIUMAOJIU";

    /**
     * 威高医疗
     */
    public final static String CUSTOMIZE_WEIGAO = "WEIGAO";

    /**
     * 东明
     */
    public final static String CUSTOMIZE_TONGMING = "TONGMING";

    /**
     * 和府捞面
     */
    public final static String CUSTOMIZE_HEFU = "HEFU";

    /**
     * 国药器械
     */
    public final static String CUSTOMIZE_GUOYAO = "GUOYAO";

    /**
     * 优伊萌
     */
    public final static String CUSTOMIZE_YYM = "YYM";

    /**
     * 中国燃气
     */
    public final static String CUSTOMIZE_ZG_NRP = "ZG_NRP";

    /**
     * 大昌行
     */
    public final static String CUSTOMIZE_DCH = "DCH";

    /**
     * 立马
     */
    public final static String CUSTOMIZE_LIMA = "LIMA";

    /**
     * 鹏驰五金
     */
    public final static String CUSTOMIZE_EG = "EG";

    /**
     * 吉野家
     */
    public final static String CUSTOMIZE_JYJ = "JYJ";

    /**
     * 雅迪
     */
    public final static String CUSTOMIZE_YADI = "YADI";

    /**
     * 喜家德
     */
    public final static String CUSTOMIZE_XJD = "XJD";

    /**
     * Tims 天好咖啡
     */
    public final static String CUSTOMIZE_TIMS = "TIMS";

    /**
     * 唐宫
     */
    public final static String CUSTOMIZE_TG = "TG";

    /**
     * 五芳斋
     */
    public final static String CUSTOMIZE_WFZ = "WFZ";

    /**
     * 荟臻医疗
     */
    public final static String CUSTOMIZE_HYGEIA = "HYGEIA";

    /**
     * 百联
     */
    public final static String CUSTOMIZE_BAILIAN = "BAILIAN";

    /**
     * 所有定制开发的版本标识
     */
    public static List<String> values() {
        Object[] fieldsValue = ReflectUtil.getFieldsValue(Customize.class);
        return Arrays.stream(fieldsValue).map(String::valueOf).collect(Collectors.toList());
    }
}

==> phoenix-starter-cloudt-0.1.21.8-20240730.015143-1-sources.jar: com/elitesland/cbpl/unicom/context/Customize.java <==
package com.elitesland.cbpl.unicom.context;

import cn.hutool.core.util.ReflectUtil;
import io.swagger.annotations.ApiModel;
import lombok.Data;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author eric.hao
 * @since 2022/03/21
 */
@Data
@ApiModel("定制开发版本")
public class Customize {

    /**
     * 通用标准实施
     */
    public final static String CUSTOMIZE_STANDARD = "STANDARD";

    /**
     * 九毛九餐饮
     */
    public final static String CUSTOMIZE_JIUMAOJIU = "JIUMAOJIU";

    /**
     * 威高医疗
     */
    public final static String CUSTOMIZE_WEIGAO = "WEIGAO";

    /**
     * 东明
     */
    public final static String CUSTOMIZE_TONGMING = "TONGMING";

    /**
     * 和府捞面
     */
    public final static String CUSTOMIZE_HEFU = "HEFU";

    /**
     * 国药器械
     */
    public final static String CUSTOMIZE_GUOYAO = "GUOYAO";

    /**
     * 优伊萌
     */
    public final static String CUSTOMIZE_YYM = "YYM";

    /**
     * 中国燃气
     */
    public final static String CUSTOMIZE_ZG_NRP = "ZG_NRP";

    /**
     * 大昌行
     */
    public final static String CUSTOMIZE_DCH = "DCH";

    /**
     * 立马
     */
    public final static String CUSTOMIZE_LIMA = "LIMA";

    /**
     * 鹏驰五金
     */
    public final static String CUSTOMIZE_EG = "EG";

    /**
     * 吉野家
     */
    public final static String CUSTOMIZE_JYJ = "JYJ";

    /**
     * 雅迪
     */
    public final static String CUSTOMIZE_YADI = "YADI";

    /**
     * 喜家德
     */
    public final static String CUSTOMIZE_XJD = "XJD";

    /**
     * Tims 天好咖啡
     */
    public final static String CUSTOMIZE_TIMS = "TIMS";

    /**
     * 唐宫
     */
    public final static String CUSTOMIZE_TG = "TG";

    /**
     * 五芳斋
     */
    public final static String CUSTOMIZE_WFZ = "WFZ";

    /**
     * 荟臻医疗
     */
    public final static String CUSTOMIZE_HYGEIA = "HYGEIA";

    /**
     * 百联
     */
    public final static String CUSTOMIZE_BAILIAN = "BAILIAN";

    /**
     * 甜啦啦
     */
    public final static String CUSTOMIZE_TIANLALA = "TIANLALA";

    /**
     * 毕得
     */
    public final static String CUSTOMIZE_BIDE = "BIDE";

    /**
     * 所有定制开发的版本标识
     */
    public static List<String> values() {
        Object[] fieldsValue = ReflectUtil.getFieldsValue(Customize.class);
        return Arrays.stream(fieldsValue).map(String::valueOf).collect(Collectors.toList());
    }
}
